@@ -121,7 +121,7 @@ func subAVX2() {
 // Why these permutations?  There are two reasons: these are reasonable
 // easy to implement and they pull sequential butterflies in the NTT apart.
 // Recall, namely, that on the fifth layer of the NTT we're computing
-// butteflies between indices
+// butterflies between indices
 //
 //      abcd0fgh  abcd1fgh
 //
@@ -701,7 +701,7 @@ func nttAVX2() {
 		// which pairs to flip.  We try to keep the permutations as local
 		// as possible: there is only mixing between xs[0], xs[1], xs[2]
 		// and xs[3].  As an added benefit this ensures that the final
-		// complete permuation is convenient for multiplication.
+		// complete permutation is convenient for multiplication.
 
 		VMOVDQU(Mem{Base: zetasPtr, Disp: 32 * (9 + offset*4)}, zs[0])
 		VMOVDQU(Mem{Base: zetasPtr, Disp: 32 * (9 + offset*4 + 1)}, zs[1])
@@ -1147,7 +1147,7 @@ func normalizeAVX2() {
 }
 
 func main() {
-	ConstraintExpr("amd64")
+	ConstraintExpr("amd64,!purego")
 
 	addAVX2()
 	subAVX2()
